pub struct CacheLock { /* private fields */ }Expand description
Guard that holds a file lock until dropped.
The lock is automatically released when the guard goes out of scope.
Implementations
Sourceimpl CacheLock
impl CacheLock
Sourcepub fn acquire_exclusive(cache_dir: &Utf8Path, version: &str) -> Result<Self>
pub fn acquire_exclusive(cache_dir: &Utf8Path, version: &str) -> Result<Self>
Acquires an exclusive lock for a specific version.
Use exclusive locks when downloading or populating the cache to prevent concurrent writes.
Errors
Returns an error if the lock file cannot be created or the lock cannot be acquired.
Examples
use camino::Utf8Path;
use pg_embedded_setup_unpriv::cache::CacheLock;
let cache_dir = Utf8Path::new("/tmp/pg-cache");
let _lock = CacheLock::acquire_exclusive(cache_dir, "17.4.0")?;
// Exclusive access to version 17.4.0 cache entryAcquires a shared lock for a specific version.
Use shared locks when reading from the cache to allow concurrent reads whilst blocking writes.
Errors
Returns an error if the lock file cannot be created or the lock cannot be acquired.
Examples
use camino::Utf8Path;
use pg_embedded_setup_unpriv::cache::CacheLock;
let cache_dir = Utf8Path::new("/tmp/pg-cache");
let _lock = CacheLock::acquire_shared(cache_dir, "17.4.0")?;
// Shared access to version 17.4.0 cache entryTrait Implementations